@@ -22,9 +22,17 @@ cellStats <- function(x, stat='mean', ...) {
 		}
 	}
 	
+	stdev <- function(x, na.rm=TRUE) {
+		if (na.rm) {
+			x <- na.omit(x)
+		}
+		sqrt(mean((x-mean(x))^2))
+	}
+	
 	if (nlayers(x) == 1) {	makeMat = TRUE 	} else { makeMat = FALSE }
 	
 
+	
 	stat <- .makeTextFun(stat)
 	tryinmem <- TRUE
 	if (class(stat) == 'character') {
@@ -54,9 +62,9 @@ cellStats <- function(x, stat='mean', ...) {
 				} else if (stat == "sum" ) {
 					return( colSums(x, na.rm=TRUE) )
 				
-				} else if (stat == 'min')  { stat <- min 
+				} else if (stat == 'min') { stat <- min 
 				} else if (stat == 'max') { stat <- max 
-				} else if (stat == 'sd') { stat <- sd 
+				} else if (stat == 'sd')  { stat <- sd 
 				} else if (stat == 'countNA') { stat <- function(x, na.rm){ sum(is.na(x)) } 
 				} else {
 					stop('stat (character type) unknown')
@@ -66,7 +74,7 @@ cellStats <- function(x, stat='mean', ...) {
 		}
 	} 
 	
-	stat <- .makeTextFun(stat)
+	#stat <- .makeTextFun(stat)
 	if (class(stat) != 'character') {
 		stop('cannot use this function for large files')
 	}
@@ -128,7 +136,7 @@ cellStats <- function(x, stat='mean', ...) {
 		} else if (stat == 'sd') {
 			st <- colSums(d, na.rm=TRUE) + st
 			cnt <- cnt + cells
-			sumsq <- apply( d^2 , 2, sum) + sumsq
+			sumsq <- apply( d^2 , 2, sum, na.rm=TRUE) + sumsq
 
 		} else if (stat=='countNA') {
 			st <- st + nas
@@ -148,7 +156,8 @@ cellStats <- function(x, stat='mean', ...) {
 		
 	if (stat == 'sd') {
 		meansq <- (st/cnt)^2
-		st <- sqrt( (1 / cnt) * sumsq - meansq )
+		# cnt/(cnt-1) to use n-1, as in sd 
+		st <- sqrt(( (sumsq / cnt) - meansq ) * (cnt/(cnt-1)))
 	} else if (stat == 'mean') {
 		st <- st / cnt
 	} else if (stat == 'skew') {
